<!DOCTYPE html>
<html>
<head>
	<title>QUnit Test Suite</title>
  <link rel="stylesheet" href="{% url qunit_css %}" type="text/css" media="screen">
  <script type="text/javascript" src="{% url qunit_js %}"></script>
  {% for url in suite.extra_urls %}
    <script type="text/javascript" src="{{ url }}"></script>
  {% endfor %}
  {% for url in suite.extra_media_urls %}
    <script type="text/javascript" src="{{ MEDIA_URL }}{{ url }}"></script>
  {% endfor %}
  {% for file in files %}
    <script type="text/javascript" src="{% url qunit_test file %}"></script>
  {% endfor %}
</head>
<body>
  <h1 id="qunit-header">QUnit Test Suite ({{ suite.name|capfirst }})</h1>
	<h2 id="qunit-banner"></h2>
	<div id="qunit-testrunner-toolbar"></div>
  {% if in_directory or subsuites %}
  <div id="navigation">
    {% if in_subdirectory %}
    <a href="{% url qunit_test_overview previous_directory %}">..</a>
    {% endif %}

    {% for suite in subsuites %}
    <a href="{{ suite }}/">{{ suite }}</a>
    {% endfor %}
  </div>
  {% endif %}
	<h2 id="qunit-userAgent"></h2>
	<ol id="qunit-tests"></ol>
</body>
</html>
